This crate provides helper functions for stack analysis on AVR.
estimate_unused_stack_space: Estimate the number of stack bytes that have never been used.
Initialization of stack space
The main crate must call the init_stack_pattern macro once to define the stack initialization function.
On initialization, all of the stack space is overwritten with a byte PATTERN by the macro.
The code that does this runs from the linker section .init4.
Macros
- init_
stack_ pattern - Define an
.init4function to initialize the stack.
Constants
- PATTERN
- Memory pattern for unused stack space.
Functions
- estimate_
unused_ stack_ space - Returns the number of stack bytes that have never been written to.